Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(92)

Unified Diff: ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h

Issue 2888533002: Identify MostVisited by item instead of URL (Closed)
Patch Set: Address comments Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/chrome/browser/ui/content_suggestions/content_suggestions_collection_updater.mm ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h
diff --git a/ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h b/ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h
index 63d61de296d88c0def674cfd5651de5ed3725ebb..99071cbc68fc4a1e96e97add1ff9187b49e00849 100644
--- a/ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h
+++ b/ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h
@@ -5,9 +5,9 @@
#ifndef IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_DATA_SINK_H_
#define IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_DATA_SINK_H_
+@class CollectionViewItem;
@class ContentSuggestionIdentifier;
@class ContentSuggestionsSectionInformation;
-class GURL;
// Data sink for the ContentSuggestions. It will be notified when new data needs
// to be pulled.
@@ -36,8 +36,8 @@ class GURL;
// now, removing the current content.
- (void)reloadSection:(ContentSuggestionsSectionInformation*)sectionInfo;
-// Notifies the Data Sink that a new favicon is available for the |URL|.
-- (void)faviconAvailableForURL:(const GURL&)URL;
+// Notifies the Data Sink that a new favicon is available for the |item|.
+- (void)faviconAvailableForItem:(CollectionViewItem<SuggestedContent>*)item;
@end
« no previous file with comments | « ios/chrome/browser/ui/content_suggestions/content_suggestions_collection_updater.mm ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698